# helixdam

This is a Python wrapper around the Perforce Helix Dam REST API to make it easier
and more pythonic to use.

Some names of methods have been changed from the REST API to reflect the names
of properties and fields in Helix DAM more closely, rather than the legacy Teamhub
names that the REST API was built on top of.

Currently a work in progress, so more documentation will be added here later!